//----------------------------------------------------------------------------
//  Project BIOSData
//  Zeal SoftStudio
//  Copyright (c) 2003, Zeal SoftStudio. All Rights Reserved.
//
//  SUBSYSTEM:    BIOSData Application
//  FILE:         biosdtdc.cpp
//  AUTHOR:       Hai Li
//
// BIOSData sample shows how to read COM and LPT ports base address and BIOS date.
// www.zealsoftstudio.com
// support@zealsoft.com
//
//  OVERVIEW
//  ~~~~~~~~
//  Source file for implementation of TBIOSDataDlgClient (TDialog).
//
//----------------------------------------------------------------------------

#include <owl/pch.h>

#include "biosdtap.h"
#include "biosdtdc.h"
#include "MemAcc.h"

//
// Build a response table for all messages/commands handled by the application.
//
DEFINE_RESPONSE_TABLE1(TBIOSDataDlgClient, TDialog)
//{{TBIOSDataDlgClientRSP_TBL_BEGIN}}
  EV_BN_CLICKED(IDOK, BNClicked),
//{{TBIOSDataDlgClientRSP_TBL_END}}
END_RESPONSE_TABLE;


//{{TBIOSDataDlgClient Implementation}}


//--------------------------------------------------------
// TBIOSDataDlgClient
// ~~~~~~~~~~
// Construction/Destruction handling.
//
TBIOSDataDlgClient::TBIOSDataDlgClient(TWindow* parent, TResId resId, TModule* module)
:
  TDialog(parent, resId, module)
{
  // INSERT>> Your constructor code here.
}


TBIOSDataDlgClient::~TBIOSDataDlgClient()
{
  Destroy();

  // INSERT>> Your destructor code here.
}

// Get the BIOS date
void GetBIOSDate(char* s)
{
   int i;
	char b;

   for(i = 1; i <= 10; i++)
	{
        b = maPeekB(V86_To_PhyAddress(0xFFFF, i + 4));
        s[i - 1] = b;
        if(b == 0)
			break;
   }
}

void TBIOSDataDlgClient::BNClicked()
{
  // INSERT>> Your code here.
    char sError[255];

    // Open the library
    if(!maOpenLibrary())
	{
        maGetLastState(sError);
        MessageBox(sError, "Error", MB_ICONSTOP);
        return;
	}


   SendDlgItemMessage(IDC_LISTBOX1, LB_RESETCONTENT);

	int i, nAddress;
	char s[256];

	// COM ports
	for(i = 1; i <= 4; i++)
	{
		nAddress = maPeekW(0x400 + (i - 1) * 2);
		if(maGetLastState(sError) != ERROR_SUCCESS)
		{
			MessageBox(sError, "Error", MB_ICONSTOP);
			return;
		}
		else if(nAddress)
		{
			wsprintf(s, "COM%d: 0x%x", i, nAddress);
         SendDlgItemMessage(IDC_LISTBOX1, LB_ADDSTRING, 0, (LPARAM)s);
		}
		else
		{
			wsprintf(s, "COM%d: absent", i);
         SendDlgItemMessage(IDC_LISTBOX1, LB_ADDSTRING, 0, (LPARAM)s);
		}
	}

	// LPT ports
	for(i = 1; i <= 3; i++)
	{
		nAddress = maPeekW(0x408 + (i - 1) * 2);
		if(maGetLastState(sError) != ERROR_SUCCESS)
		{
			MessageBox(sError, "Error", MB_ICONSTOP);
			return;
		}
		else if(nAddress)
		{
			wsprintf(s, "LPT%d: 0x%x", i, nAddress);
         SendDlgItemMessage(IDC_LISTBOX1, LB_ADDSTRING, 0, (LPARAM)s);
		}
		else
		{
			wsprintf(s, "LPT%d: absent", i);
         SendDlgItemMessage(IDC_LISTBOX1, LB_ADDSTRING, 0, (LPARAM)s);
		}
	}

   char s1[50];
   GetBIOSDate(s1);
   strcpy(s, "BIOS Date: ");
   strcat(s, s1);
	SetDlgItemText(IDC_BIOSDATE, s);

	// Close the library
    maCloseLibrary();
}

