//----------------------------------------------------------------------------
//  Project PCISample
//  Zeal SoftStudio
//  Copyright (c) 2003 Zeal SoftStudio. All Rights Reserved.
//
//  SUBSYSTEM:    PCISample Application
//  FILE:         pcisampleapp.cpp
//  AUTHOR:       Hai Li
//
//  OVERVIEW
//  ~~~~~~~~
//  Source file for implementation of TPCISampleApp (TApplication).
//
//----------------------------------------------------------------------------

#include <owl/pch.h>

#include <owl/buttonga.h>
#include <owl/statusba.h>
#include <classlib/cmdline.h>
#include <winsys/registry.h>
#include <stdio.h>

#include "pcisampleapp.h"
#include "pcisampledlgclient.h"                        // Definition of client class.


//{{TPCISampleApp Implementation}}


//
// Build a response table for all messages/commands handled
// by the application.
//
DEFINE_RESPONSE_TABLE1(TPCISampleApp, TApplication)
//{{TPCISampleAppRSP_TBL_BEGIN}}
  EV_COMMAND(CM_HELPABOUT, CmHelpAbout),
//{{TPCISampleAppRSP_TBL_END}}
END_RESPONSE_TABLE;


//--------------------------------------------------------
// TPCISampleApp
//
TPCISampleApp::TPCISampleApp() : TApplication("PCI Sample")
{

  // INSERT>> Your constructor code here.
}


TPCISampleApp::~TPCISampleApp()
{
  // INSERT>> Your destructor code here.
}


//--------------------------------------------------------
// TPCISampleApp
// ~~~~~
// Application intialization.
//
void TPCISampleApp::InitMainWindow()
{
  if (nCmdShow != SW_HIDE)
    nCmdShow = (nCmdShow != SW_SHOWMINNOACTIVE) ? SW_SHOWNORMAL : nCmdShow;

  TSDIDecFrame* frame = new TSDIDecFrame(0, GetName(), 0, true);
  frame->SetFlag(wfShrinkToClient);

  // Assign ICON w/ this application.
  //
  frame->SetIcon(this, IDI_SDIAPPLICATION);
  frame->SetIconSm(this, IDI_SDIAPPLICATION);


  TStatusBar* sb = new TStatusBar(frame, TGadget::Recessed,
                                  TStatusBar::CapsLock        |
                                  TStatusBar::NumLock         |
                                  TStatusBar::ScrollLock);
  frame->Insert(*sb, TDecoratedFrame::Bottom);

  SetMainWindow(frame);

}


//--------------------------------------------------------
// TPCISampleApp
// ~~~~~
// Application instance initialization.
//
void TPCISampleApp::InitInstance()
{
  TApplication::InitInstance();

  ProcessCmdLine(lpCmdLine);
}


//--------------------------------------------------------
// TPCISampleApp
// ~~~~~
// Process command line parameters.
//
void TPCISampleApp::ProcessCmdLine(char * CmdLine)
{
  TCmdLine cmd(CmdLine);

  while (cmd.Kind != TCmdLine::Done) {
    if (cmd.Kind == TCmdLine::Option) {
      if (strnicmp(cmd.Token, "unregister", cmd.TokenLen) == 0) {
        UnRegisterInfo();
        return;
      }
    }
    cmd.NextToken();
  }

  RegisterInfo();
}


//--------------------------------------------------------
// TPCISampleApp
// ~~~~~
// Register application info.
//
void TPCISampleApp::RegisterInfo()
{
  TAPointer<char> buffer = new char[_MAX_PATH];

  GetModuleFileName(buffer, _MAX_PATH);

  TRegKey(TRegKey::ClassesRoot, "PCISample.Application\\DefaultIcon").SetDefValue(0, REG_SZ, buffer, strlen(buffer));
  strcat(buffer, ",1");
}


//--------------------------------------------------------
// TPCISampleApp
// ~~~~~
// Unregister application info.
//
void TPCISampleApp::UnRegisterInfo()
{
  TAPointer<char> buffer = new char[_MAX_PATH];

  GetModuleFileName(buffer, _MAX_PATH);

  TRegKey(TRegKey::ClassesRoot, "PCISample.Application").DeleteKey("DefaultIcon");
  TRegKey(TRegKey::ClassesRoot, "PCISample.Document.1").DeleteKey("DefaultIcon");

  TRegKey::ClassesRoot.DeleteKey("PCISample.Application");
}



//{{TSDIDecFrame Implementation}}


TSDIDecFrame::TSDIDecFrame(TWindow* parent, const char far* title, TWindow* clientWnd, bool trackMenuSelection, TModule* module)
:
  TDecoratedFrame(parent, title, !clientWnd ? new TPCISampleDlgClient(0) : clientWnd, trackMenuSelection, module)
{
  // INSERT>> Your constructor code here.

}


TSDIDecFrame::~TSDIDecFrame()
{
  // INSERT>> Your destructor code here.

}


void TSDIDecFrame::SetupWindow()
{
  TDecoratedFrame::SetupWindow();
  TRect  r;
  GetWindowRect(r);

  r.bottom += 30;
  SetWindowPos(0, r, SWP_NOZORDER | SWP_NOMOVE);

  // INSERT>> Your code here.

}


//--------------------------------------------------------
// TPCISampleApp
// ~~~~~~~~~~~
// Menu Help About PCISample command
//
void TPCISampleApp::CmHelpAbout()
{
}



int OwlMain(int , char* [])
{
  TPCISampleApp   app;
  return app.Run();
}
